@@ -7,7 +7,7 @@ use Test::Deep::Cmp;
 use JSON;
 use Exporter::Lite;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 our @EXPORT = qw(json);
 
@@ -33,7 +33,8 @@ sub descend {
 
 sub diagnostics {
     my $self = shift;
-    return $self->{error};
+    return $self->{error} if defined $self->{error} && length $self->{error};
+    return $self->{val}->diagnostics(@_);
 }
 
 1;
